@@ -14,4 +14,14 @@ if [ ! -d /sys/firmware/efi/efivars ]; then
     sudo sed -i -e 's|defaultFileSystemType:  "xfs"|defaultFileSystemType:  "ext4"|' /usr/share/calamares/modules/partition.conf
 fi
 
-pkexec --disable-internal-agent env DBUS_SESSION_BUS_ADDRESS="$DBUS_SESSION_BUS_ADDRESS" DISPLAY="$DISPLAY" HOME="$HOME" QT_STYLE_OVERRIDE="$QT_STYLE_OVERRIDE" QT_QPA_PLATFORMTHEME="$QT_QPA_PLATFORMTHEME" QT_XCB_FORCE_SOFTWARE_OPENGL="$QT_XCB_FORCE_SOFTWARE_OPENGL" XAUTHORITY="$XAUTHORITY" XDG_CURRENT_DESKTOP="$XDG_CURRENT_DESKTOP" "/usr/bin/calamares" "-D6" "$@" > installation.log
+pkexec --disable-internal-agent env \
+    DBUS_SESSION_BUS_ADDRESS="$DBUS_SESSION_BUS_ADDRESS" \
+    WAYLAND_DISPLAY="$WAYLAND_DISPLAY" \
+    XDG_RUNTIME_DIR="$XDG_RUNTIME_DIR" \
+    HOME="$HOME" \
+    QT_STYLE_OVERRIDE="$QT_STYLE_OVERRIDE" \
+    QT_QPA_PLATFORMTHEME="$QT_QPA_PLATFORMTHEME" \
+    QT_QPA_PLATFORM="wayland" \
+    XDG_CURRENT_DESKTOP="$XDG_CURRENT_DESKTOP" \
+    XDG_SESSION_TYPE="wayland" \
+    "/usr/bin/calamares" "-D6" "$@" > installation.log
