@@ -29,6 +29,7 @@ def run():
 
     install_path = libcalamares.globalstorage.value("rootMountPoint")
     fw_type = libcalamares.globalstorage.value("firmwareType")
+    bootchoice = libcalamares.globalstorage.value("packagechooser_bootchoice")
 
     # remove any db.lck
     db_lock = os.path.join(install_path, "var/lib/pacman/db.lck")
@@ -72,7 +73,7 @@ def run():
             ['pacman', '-Rns', '--noconfirm', 'efibootmgr', 'refind-efi', 'limine'])
 
     if bootchoice == 'limine':
-        print('Removing refind-efi packages)
+        print('Removing refind-efi packages')
         libcalamares.utils.target_env_call(
             ['pacman', '-Rns', '--noconfirm', 'refind-efi'])
 
